"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMutation = void 0;
const vue_1 = require("vue");
const core_1 = require("react-query/core");
const utils_1 = require("./utils");
const useQueryClient_1 = require("./useQueryClient");
function useMutation(arg1, arg2, arg3) {
    const options = utils_1.parseMutationArgs(arg1, arg2, arg3);
    const queryClient = useQueryClient_1.useQueryClient();
    const observer = new core_1.MutationObserver(queryClient, options);
    const state = vue_1.reactive(observer.getCurrentResult());
    const unsubscribe = observer.subscribe(() => {
        utils_1.updateState(state, observer.getCurrentResult());
        if (state.error && observer.options.useErrorBoundary) {
            throw state.error;
        }
    });
    const mutate = (variables, mutateOptions) => {
        observer.mutate(variables, mutateOptions).catch(() => { });
    };
    vue_1.watchEffect(() => {
        observer.setOptions(options);
    });
    vue_1.onUnmounted(() => {
        unsubscribe();
    });
    return Object.assign(state, {
        mutate,
        mutateAsync: state.mutate,
    });
}
exports.useMutation = useMutation;
